@@ -17,6 +17,7 @@ def fct_min_gamma(params,X,cw,w,x):
   # Calculate the resulting score
   t = X@(cw*w**(params[0]/(1-params[0]))).T
   t= t[:,0]
+  t= (t-np.mean(t))/(np.std(t)+1e-10)
 
   # Calculate the monotonic NL relation
   paramsm = params[1:]
@@ -46,6 +47,7 @@ class regression:
     self.all_w = []
     self.all_b = []
     self.all_std = []
+    self.meanstd = []
     self.all_gamma = []
     self.all_paramsm = []
     self.preprocess = True
@@ -68,6 +70,7 @@ class regression:
     for nb_comp in range(int(np.min([len(self.all_w),comp]))):
       t = X@self.all_w[nb_comp].T
       t = t[:,0]
+      t = (t-self.meanstd[nb_comp][0])/(self.meanstd[nb_comp][1]+1e-10)
       paramsm = self.all_paramsm[nb_comp]
       g = np.array([t]).T*np.abs(np.array([paramsm[:int(len(paramsm)/2)]])) + \
           np.array([paramsm[int(len(paramsm)/2):]])
@@ -162,6 +165,7 @@ class regression:
         # Linear coeff calculation
         t = X@(cw*w**(params[0]/(1-params[0]))).T
         t = t[:,0]
+        t= (t-np.mean(t))/(np.std(t)+1e-10)
         paramsm = params[1:]
         g = np.array([t]).T*np.abs(np.array([paramsm[:int(len(paramsm)/2)]])) + \
           np.array([paramsm[int(len(paramsm)/2):]])
@@ -203,6 +207,8 @@ class regression:
       w_final = cw*w**(params[0]/(1-params[0]))
       t = X@(cw*w**(params[0]/(1-params[0]))).T
       t = t[:,0]
+      self.meanstd.append([np.mean(t),np.std(t)])
+      t = (t-np.mean(t))/np.std(t)
       paramsm = params[1:]
       g = np.array([t]).T*np.abs(np.array([paramsm[:int(len(paramsm)/2)]])) + \
         np.array([paramsm[int(len(paramsm)/2):]])
